@@ -9,7 +9,7 @@ __all__ = [
     'errors',
     'keys',
     'tools',
-    'loop',
+    'loop'
 ]
 # Define and set global event loop
 loop = new_event_loop()
