@@ -2,9 +2,18 @@
 
 from os import urandom
 from random import SystemRandom
-from hashlib import sha256, scrypt
-from typing import Generator, Union, Optional
 
+from hashlib import sha256
+try:
+    from hashlib import scrypt
+except ImportError:
+    # This is for ReadTheDocs. Maybe TODO.
+    from Crypto.Protocol.KDF import scrypt
+
+from typing import (
+    AsyncGenerator, 
+    Union, Optional
+)
 from base64 import (
     urlsafe_b64encode,
     urlsafe_b64decode 
@@ -129,7 +138,7 @@ class Key:
     def __getitem__(self, key) -> int:
         return self._key[key]
     
-    def __iter__(self) -> Generator[int, None, None]:
+    def __iter__(self) -> AsyncGenerator[int, None]:
         for i in self._key:
             yield i
     
